@@ -42,7 +42,7 @@ class HypergraphFormatter:
            The hypernode to style.
         """
         return {"shape": "ellipse",
-                "label": str(self.hypergraph.node_label(node))}
+                "label": str(node.label)}
 
     def hyperedge_node_attrs(self, edge):
         """
@@ -57,7 +57,7 @@ class HypergraphFormatter:
         """
         if self._show_hyperedges:
             return {"shape": "rect",
-                    "label": str(self.hypergraph.label(edge))}
+                    "label": str(edge.label)}
         else:
             return {"shape": "point"}
 
@@ -116,7 +116,7 @@ class HypergraphFormatter:
                         self.hyperedge_attrs(edge))
         return graph
 
-    def to_image(self, filename):
+    def to_image(self, filename, layout="dot"):
         """
         Write out to an image.
 
@@ -132,11 +132,18 @@ d        ------------
 
         NetworkX Graph
         """
-        agraph = self.to_graphviz()
+        agraph = self.to_graphviz(layout)
         agraph.write("/tmp/tmp.dot")
         agraph.draw(filename)
 
-    def to_graphviz(self):
+    def to_pydot(self):
+        G = self.to_networkx()
+        pydot = nx.drawing.to_pydot(G)
+        for k, v in self.graph_attrs().iteritems():
+            pydot.set(k, v)
+        return pydot
+
+    def to_graphviz(self, layout="dot"):
         subgraphs = {}
         G = self.to_networkx()
         agraph = nx.drawing.to_agraph(G)
@@ -158,7 +165,7 @@ d        ------------
             subgraph.graph_attr.update(self.subgraph_format(sub))
         agraph.graph_attr.update(self.graph_attrs())
 
-        agraph.layout("dot")
+        agraph.layout(layout)
         return agraph
 
     def to_ipython(self):
